==> ejc-rmat-api-3.0.0-20210617.102549-13-sources.jar: com/ejianc/business/rmat/vo/RentRecordFeeVO.java <==
package com.ejianc.business.rmat.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;

/**
 * <p>
 * 其他费用
 * </p>
 *
 * @author yqls
 * @since 2020-06-09
 */
public class RentRecordFeeVO extends BaseVO {

    private static final long serialVersionUID = 1L;

    /**
     * 记录合同主键
     */
    private Long recordId;

    /**
     * 合同主键
     */
    private Long contractId;

    /**
     * 原合同子表主键
     */
    private Long contractFeeId;

    /**
     * 费用类型
     */
    private String feeType;

    /**
     * 金额
     */
    private BigDecimal money;

    /**
     * 备注
     */
    private String memo;

    public Long getRecordId() {
        return recordId;
    }

    public void setRecordId(Long recordId) {
        this.recordId = recordId;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getContractFeeId() {
        return contractFeeId;
    }

    public void setContractFeeId(Long contractFeeId) {
        this.contractFeeId = contractFeeId;
    }
    public String getFeeType() {
        return feeType;
    }

    public void setFeeType(String feeType) {
        this.feeType = feeType;
    }
    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }


}

==> ejc-rmat-api-3.0.0-20210823.033406-62-sources.jar: com/ejianc/business/rmat/vo/RentRecordFeeVO.java <==
package com.ejianc.business.rmat.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;

/**
 * <p>
 * 其他费用
 * </p>
 *
 * @author yqls
 * @since 2020-06-09
 */
public class RentRecordFeeVO extends BaseVO {

    private static final long serialVersionUID = 1L;

    /**
     * 记录合同主键
     */
    private Long recordId;

    /**
     * 合同主键
     */
    private Long contractId;

    /**
     * 原合同子表主键
     */
    private Long contractFeeId;

    /**
     * 费用类型
     */
    private String feeType;

    /**
     * 金额
     */
    private BigDecimal money;

    /**
     * 备注
     */
    private String memo;

    private Integer srcSupplementFlag; // 是否来源补充协议(1:是，0：否)
    private Long srcSupplementId; // 来源补充协议主表ID
    private Long srcSupplementDetailId; // 来源补充协议明细ID

    public Integer getSrcSupplementFlag() {
        return srcSupplementFlag;
    }

    public void setSrcSupplementFlag(Integer srcSupplementFlag) {
        this.srcSupplementFlag = srcSupplementFlag;
    }

    public Long getSrcSupplementId() {
        return srcSupplementId;
    }

    public void setSrcSupplementId(Long srcSupplementId) {
        this.srcSupplementId = srcSupplementId;
    }

    public Long getSrcSupplementDetailId() {
        return srcSupplementDetailId;
    }

    public void setSrcSupplementDetailId(Long srcSupplementDetailId) {
        this.srcSupplementDetailId = srcSupplementDetailId;
    }

    public Long getRecordId() {
        return recordId;
    }

    public void setRecordId(Long recordId) {
        this.recordId = recordId;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getContractFeeId() {
        return contractFeeId;
    }

    public void setContractFeeId(Long contractFeeId) {
        this.contractFeeId = contractFeeId;
    }
    public String getFeeType() {
        return feeType;
    }

    public void setFeeType(String feeType) {
        this.feeType = feeType;
    }
    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }


}
